@@ -25,16 +25,31 @@ class DetectSpineMRIRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'imageprocess', '2020-03-20', 'DetectSpineMRI','imageprocess')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_OrgName(self): # String
+		return self.get_body_params().get('OrgName')
 
-	def get_URLLists(self):
+	def set_OrgName(self, OrgName):  # String
+		self.add_body_params('OrgName', OrgName)
+	def get_DataFormat(self): # String
+		return self.get_body_params().get('DataFormat')
+
+	def set_DataFormat(self, DataFormat):  # String
+		self.add_body_params('DataFormat', DataFormat)
+	def get_URLLists(self): # RepeatList
 		return self.get_body_params().get('URLList')
 
-	def set_URLLists(self, URLLists):
-		for depth1 in range(len(URLLists)):
-			if URLLists[depth1].get('URL') is not None:
-				self.add_body_params('URLList.' + str(depth1 + 1) + '.URL', URLLists[depth1].get('URL'))
\ No newline at end of file
+	def set_URLLists(self, URLList):  # RepeatList
+		for depth1 in range(len(URLList)):
+			if URLList[depth1].get('URL') is not None:
+				self.add_body_params('URLList.' + str(depth1 + 1) + '.URL', URLList[depth1].get('URL'))
+	def get_OrgId(self): # String
+		return self.get_body_params().get('OrgId')
+
+	def set_OrgId(self, OrgId):  # String
+		self.add_body_params('OrgId', OrgId)
